import femto.mode.HiRes16Color;
import femto.Game;
import femto.State;
import femto.input.Button;
import femto.font.TIC80;

import maps.Title;
import sprites.Dog;

class Main extends State {

    static final HiRes16Color screen = new HiRes16Color(femto.palette.A64.palette(), TIC80.font());

    Dog dog; // an animated sprite imported from Aseprite
    float angle; // floats are actually FixedPoint (23.8)
    Title titleMap;
    int counter; // variables are automatically initialized to 0 or null

    // start the game using Main as the initial state
    // and TIC80 as the menu's font
    public static void main(String[] args){
        Game.run( TIC80.font(), new Main() );
    }
    
    // Avoid allocation in a State's constructor.
    // Allocate on init instead.
    void init(){
        dog = new Dog();
        dog.run(); // "run" is one of the animations in the spritesheet
        titleMap = new Title();
    }

    // update is called by femto.Game every frame
    void update(){

        screen.clear(0);

        // Render the background layer of the tilemap
        titleMap.drawBackground(screen);

        // Move and draw the dog
        float previousX = dog.x;
        angle += 0.03f;
        dog.x = 110 + Math.cos(angle) * 70.0f;
        dog.y = 64 + Math.sin(angle) * 70.0f;
        dog.setMirrored( previousX > dog.x );
        dog.draw(screen); // Animation is updated automatically

        // render the foreground layer
        titleMap.drawForeground(screen);

        // Print some text
        counter++;
        screen.setTextPosition( 4*16+8, 16+8 );
        screen.textColor = counter;
        screen.print(((counter>>5)&1)==0 ? "ROUND" : "AND");

        screen.setTextPosition( 4*16+8, 16+16 );
        screen.textColor = 0;
        screen.print("FPS: " + screen.fps());
        
        // Update the screen with everything that was drawn
        screen.flush();
    }
    
}
